==> apache-sis-1.4-src.zip: apache-sis-1.4-src/endorsed/src/org.apache.sis.metadata/test/org/apache/sis/metadata/iso/identification/DefaultKeywordsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sis.metadata.iso.identification;

import org.apache.sis.util.SimpleInternationalString;

// Test dependencies
import org.junit.Test;
import org.apache.sis.test.TestCase;

import static org.junit.Assert.*;


/**
 * Tests {@link DefaultKeywords}.
 *
 * @author  Martin Desruisseaux (Geomatys)
 */
public final class DefaultKeywordsTest extends TestCase {
    /**
     * Creates a new test case.
     */
    public DefaultKeywordsTest() {
    }

    /**
     * Tests {@link DefaultKeywords#DefaultKeywords(CharSequence[])}.
     */
    @Test
    public void testConstructor() {
        final DefaultKeywords keywords = new DefaultKeywords("Keyword 1", "Keyword 2", "Keyword 3");
        assertArrayEquals(new Object[] {
            new SimpleInternationalString("Keyword 1"),
            new SimpleInternationalString("Keyword 2"),
            new SimpleInternationalString("Keyword 3")
        }, keywords.getKeywords().toArray());
    }
}

==> apache-sis-1.5-src.zip: apache-sis-1.5-src/endorsed/src/org.apache.sis.metadata/test/org/apache/sis/metadata/iso/identification/DefaultKeywordsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sis.metadata.iso.identification;

import org.apache.sis.util.SimpleInternationalString;

// Test dependencies
import org.junit.jupiter.api.Test;
import static org.junit.jupiter.api.Assertions.*;
import org.apache.sis.test.TestCase;


/**
 * Tests {@link DefaultKeywords}.
 *
 * @author  Martin Desruisseaux (Geomatys)
 */
public final class DefaultKeywordsTest extends TestCase {
    /**
     * Creates a new test case.
     */
    public DefaultKeywordsTest() {
    }

    /**
     * Tests {@link DefaultKeywords#DefaultKeywords(CharSequence[])}.
     */
    @Test
    public void testConstructor() {
        final var keywords = new DefaultKeywords("Keyword 1", "Keyword 2", "Keyword 3");
        assertArrayEquals(new Object[] {
            new SimpleInternationalString("Keyword 1"),
            new SimpleInternationalString("Keyword 2"),
            new SimpleInternationalString("Keyword 3")
        }, keywords.getKeywords().toArray());
    }
}
